using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using AxDIAMONDTOUCHLib;
using GestureEngine;
using GsiDemo;

namespace Multimodal_Sketch
{
    public partial class Form1 : Form
    {
        private Color[] OriginalColors = { Color.Red, Color.Green, Color.Blue, Color.Yellow };
        private Color[] UserColors = { Color.Red, Color.Green, Color.Blue, Color.Yellow };        
        private Point[] LastPoint;
        private int TotalUsers;
        public Form1()
        {
            InitializeComponent();
            this.DoubleBuffered = true;
            multiModalMultiUserIntegrator1.Start();
            multiModalMultiUserIntegrator1.Started += new EventHandler(multiModalMultiUserIntegrator1_Started);
        }

        void multiModalMultiUserIntegrator1_Started(object sender, EventArgs e)
        {
            TotalUsers = multiModalMultiUserIntegrator1.GetTotalGestureClients();
            LastPoint = new Point[TotalUsers];            
            for (int i = 0; i < LastPoint.Length; ++i)
            {
                LastPoint[i] = new Point(-1, -1);                
            }
            multiModalMultiUserIntegrator1.SetSpeechCommands("red pen,green pen,blue pen,yellow pen,increase thickness,derease thickness,clear screen,");
        }

        private void multiModalMultiUserIntegrator1_SpeechRecognition(int UserId, int SpeechIndex)
        {
            //play an audio cue 
            System.Media.SoundPlayer sp = new System.Media.SoundPlayer(@"c:\windows\media\Windows XP Information Bar.wav");
            sp.Play();
            if (SpeechIndex < 4)
                UserColors[UserId] = OriginalColors[SpeechIndex];
            else //clear the screen            
                this.CreateGraphics().Clear(this.BackColor);                            
        }

        private void multiModalMultiUserIntegrator1_PostureDown(int PostureDetected, AxDIAMONDTOUCHLib._DDiamondTouchEvents_TouchEvent e)
        {
            LastPoint[e.receiverId] = new Point(e.x, e.y);
        }

        private void multiModalMultiUserIntegrator1_GestureMove(GestureEngine.GestureEventArgs gesture, AxDIAMONDTOUCHLib._DDiamondTouchEvents_TouchEvent e)
        {
            if (!(LastPoint[e.receiverId].X == -1 && LastPoint[e.receiverId].Y == -1))
            {
                Graphics g = this.CreateGraphics();
                if ((int)GestureIndicies.OneFinger == gesture.Index)
                {
                    Pen userPen = new Pen(new SolidBrush(UserColors[e.receiverId]));
                    userPen.Width = 5;
                    userPen.EndCap = System.Drawing.Drawing2D.LineCap.Round;
                    g.DrawLine(userPen, new Point(e.x, e.y), LastPoint[e.receiverId]);
                }
                else //erase comments                
                    g.FillRectangle(new SolidBrush(this.BackColor), new Rectangle(e.left, e.top, e.right - e.left, e.bottom - e.top));                
            }
            LastPoint[e.receiverId] = new Point(e.x, e.y);
        }

        private void multiModalMultiUserIntegrator1_GestureUp(GestureEngine.GestureEventArgs gesture, AxDIAMONDTOUCHLib._DDiamondTouchEvents_TouchEvent e)
        {
            LastPoint[e.receiverId] = new Point(-1, -1);
        }
    }
}